# ia256utilities
***ia256utilities*** - is a set of useful utilities.

## Modules
* filesystem - load_json, save_json, save.

## Installation
### pip and git
$ pip install git+git://github.com/IceArrow256Studio/ia256utilities.git

### Just pip
$ pip install ia256utilities

## IDE
* PyCharm

## License
***ia256utilities*** is licensed under the MIT License, please see license.md for details.

## Authors
* IceArrow256 — main developer (icearrow256@gmail.com)
